"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = void 0;
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const path_1 = tslib_1.__importDefault(require("path"));
const generate_code_1 = tslib_1.__importDefault(require("../generator/generate-code"));
const removeDir_1 = tslib_1.__importDefault(require("../utils/removeDir"));
const helpers_1 = require("../generator/helpers");
exports.generate = async (options) => {
    const outputDir = options.generator.output;
    await fs_1.promises.mkdir(outputDir, { recursive: true });
    await removeDir_1.default(outputDir, true);
    const prismaClientPath = options.otherGenerators.find((it) => it.provider === 'prisma-client-js').output;
    const prismaClientDmmf = require(prismaClientPath)
        .dmmf;
    const config = {
        ...options.generator.config,
        outputDirPath: outputDir,
        relativePrismaOutputPath: helpers_1.toUnixPath(path_1.default.relative(outputDir, prismaClientPath)),
        absolutePrismaOutputPath: prismaClientPath.includes('node_modules')
            ? prismaClientPath.split('node_modules/')[1]
            : undefined,
    };
    if (config.emitDMMF) {
        await Promise.all([
            fs_1.promises.writeFile(path_1.default.resolve(outputDir, './dmmf.json'), JSON.stringify(options.dmmf, null, 2)),
            fs_1.promises.writeFile(path_1.default.resolve(outputDir, './prisma-client-dmmf.json'), JSON.stringify(prismaClientDmmf, null, 2)),
        ]);
    }
    // TODO: replace with `options.dmmf` when the spec match prisma client output
    await generate_code_1.default(prismaClientDmmf, config);
    return '';
};
//# sourceMappingURL=prisma-generator.js.map