"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const config_1 = require("./config");
const imports_1 = require("./imports");
const saveSourceFile_1 = tslib_1.__importDefault(require("../utils/saveSourceFile"));
const generateArgsTypeClassFromArgs = async (project, generateDirPath, fields, argsTypeName, dmmfDocument, options, inputImportsLevel = 3) => {
    const dirPath = path_1.default.resolve(generateDirPath, config_1.argsFolderName);
    const filePath = path_1.default.resolve(dirPath, `${argsTypeName}.ts`);
    const sourceFile = project.createSourceFile(filePath, undefined, {
        overwrite: true,
    });
    imports_1.generateNestJSArgImport(sourceFile);
    imports_1.generateInputsImports(sourceFile, fields
        .map((arg) => arg.selectedInputType)
        .filter((argInputType) => argInputType.kind === 'object')
        .map((argInputType) => argInputType.type), inputImportsLevel);
    imports_1.generateClassTransformerDTOImport(sourceFile);
    imports_1.generateEnumsImports(sourceFile, fields
        .map((field) => field.selectedInputType)
        .filter((argType) => argType.kind === 'enum')
        .map((argType) => argType.type), 4);
    sourceFile.addClass({
        name: argsTypeName,
        isExported: true,
        decorators: [
            {
                name: 'ArgsType',
                arguments: [],
            },
        ],
        properties: fields.map((arg) => {
            var _a;
            const isOptional = !arg.selectedInputType.isRequired;
            return {
                name: arg.typeName,
                type: arg.fieldTSType,
                hasExclamationToken: !isOptional,
                hasQuestionToken: isOptional,
                trailingTrivia: '\r\n',
                decorators: [
                    ...(arg.selectedInputType.kind === 'object'
                        ? [
                            {
                                name: 'ClassTransformer__Type',
                                arguments: [`() => ${arg.selectedInputType.type}`],
                            },
                        ]
                        : []),
                    {
                        name: 'Field',
                        arguments: [
                            `() => ${arg.typeGraphQLType}`,
                            `{ ${[
                                `nullable: ${isOptional}`,
                                ...(arg.typeName === 'take'
                                    ? [`defaultValue: ${(_a = options.defaultTake) !== null && _a !== void 0 ? _a : 20}`]
                                    : []),
                            ].join(',')} }`,
                        ],
                    },
                ],
            };
        }),
    });
    await saveSourceFile_1.default(sourceFile);
    return argsTypeName;
};
exports.default = generateArgsTypeClassFromArgs;
//# sourceMappingURL=args-class.js.map