"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DmmfDocument = void 0;
const transform_1 = require("./transform");
class DmmfDocument {
    constructor({ datamodel, schema, mappings }, options) {
        // transform bare model without fields
        this.models = datamodel.models.map(transform_1.transformBareModel);
        // then transform once again to map the fields (it requires mapped model type names)
        this.models = datamodel.models.map(transform_1.transformModelWithFields(this));
        this.datamodel = {
            models: this.models,
            enums: datamodel.enums.map(transform_1.transformEnums(this)),
        };
        this.enums = schema.enums.map(transform_1.transformEnums(this));
        this.schema = {
            ...transform_1.transformSchema(schema, this),
            enums: this.enums,
        };
        this.mappings = transform_1.transformMappings(mappings, this, options);
    }
    getModelTypeName(modelName) {
        var _a;
        return (_a = this.models.find((it) => it.name.toLocaleLowerCase() === modelName.toLocaleLowerCase())) === null || _a === void 0 ? void 0 : _a.typeName;
    }
    isModelName(typeName) {
        return this.models.some((it) => it.name === typeName);
    }
    getModelFieldAlias(modelName, fieldName) {
        var _a;
        const model = this.models.find((it) => it.name === modelName);
        return (_a = model === null || model === void 0 ? void 0 : model.fields.find((it) => it.name === fieldName)) === null || _a === void 0 ? void 0 : _a.typeFieldAlias;
    }
}
exports.DmmfDocument = DmmfDocument;
//# sourceMappingURL=dmmf-document.js.map