export declare namespace DMMF {
    interface Document {
        datamodel: Datamodel;
        schema: Schema;
        mappings: Mapping[];
    }
    interface Enum {
        name: string;
        dbName?: string | null;
        typeName: string;
        docs?: string;
        valuesMap: Array<{
            name: string;
            value: string;
        }>;
    }
    interface Datamodel {
        models: Model[];
        enums: Enum[];
    }
    interface UniqueIndex {
        name: string;
        fields: string[];
    }
    interface Model {
        name: string;
        isEmbedded: boolean;
        dbName: string | null;
        fields: Field[];
        uniqueFields: string[][];
        uniqueIndexes: UniqueIndex[];
        idFields: string[];
        typeName: string;
        docs: string | undefined;
    }
    type FieldKind = 'scalar' | 'object' | 'enum';
    interface Field {
        kind: FieldKind;
        name: string;
        isRequired: boolean;
        isList: boolean;
        isUnique: boolean;
        isId: boolean;
        type: string;
        dbNames: string[] | null;
        isGenerated: boolean;
        hasDefaultValue: boolean;
        default?: FieldDefault | string | boolean | number;
        relationToFields?: any[];
        relationOnDelete?: string;
        relationName?: string;
        typeFieldAlias?: string;
        typeGraphQLType: string;
        fieldTSType: string;
        docs: string | undefined;
    }
    interface FieldDefault {
        name: string;
        args: any[];
    }
    interface Schema {
        rootQueryType?: string;
        rootMutationType?: string;
        inputTypes: InputType[];
        outputTypes: OutputType[];
        enums: Enum[];
    }
    interface Query {
        name: string;
        args: SchemaArg[];
        output: QueryOutput;
    }
    interface QueryOutput {
        name: string;
        isRequired: boolean;
        isList: boolean;
    }
    type ArgType = string | InputType | Enum;
    interface SchemaArgInputType {
        isRequired: boolean;
        isNullable: boolean;
        isList: boolean;
        kind: FieldKind;
        argType: ArgType;
        type: string;
    }
    interface SchemaArg {
        name: string;
        isRelationFilter?: boolean;
        nullEqualsUndefined?: boolean;
        comment?: string;
        selectedInputType: SchemaArgInputType;
        typeName: string;
        typeGraphQLType: string;
        fieldTSType: string;
        hasMappedName: boolean;
    }
    interface OutputType {
        name: string;
        fields: OutputSchemaField[];
        isEmbedded?: boolean;
        modelName: string;
        typeName: string;
    }
    interface SchemaField {
        name: string;
        outputType: {
            type: string;
            isList: boolean;
            isRequired: boolean;
            kind: FieldKind;
        };
        args: SchemaArg[];
        typeGraphQLType: string;
        fieldTSType: string;
    }
    interface OutputSchemaField extends SchemaField {
        argsTypeName: string | undefined;
    }
    interface InputType {
        name: string;
        isWhereType?: boolean;
        isOrderType?: boolean;
        atLeastOne?: boolean;
        atMostOne?: boolean;
        fields: SchemaArg[];
        typeName: string;
    }
    interface Mapping {
        model: string;
        plural: string;
        actions: Action[];
        collectionName: string;
    }
    interface Action {
        name: string;
        fieldName: string;
        kind: ModelAction;
        operation: 'Query' | 'Mutation';
        method: OutputSchemaField;
        argsTypeName: string | undefined;
        outputTypeName: string;
    }
    enum ModelAction {
        findOne = "findOne",
        findMany = "findMany",
        create = "create",
        update = "update",
        updateMany = "updateMany",
        upsert = "upsert",
        delete = "delete",
        deleteMany = "deleteMany",
        aggregate = "aggregate"
    }
}
export interface BaseField {
    name: string;
    type: string | DMMF.Enum | DMMF.OutputType | DMMF.SchemaArg;
    isList: boolean;
    isRequired: boolean;
}
