"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateArgsImports = exports.generateOutputsImports = exports.generateInputsImports = exports.generateEnumsImports = exports.generateModelsImports = exports.generateResolversBarrelFile = exports.generateIndexFile = exports.generateOutputsBarrelFile = exports.generateInputsBarrelFile = exports.generateEnumsBarrelFile = exports.generateModelsBarrelFile = exports.generateArgsBarrelFile = exports.generateClassTransformerDTOImport = exports.generateClassTransformerImport = exports.generatePrismaJsonTypeImport = exports.generateGraphQLScalarImport = exports.generateGraphQLFieldsImport = exports.generateNestJSRelationsImport = exports.generateNestJSModelImport = exports.generateNestJSInputImport = exports.generateNestJSEnumImport = exports.generateNestJSCrudImport = exports.generateNestJSArgImport = void 0;
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const config_1 = require("./config");
exports.generateNestJSArgImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: '@nestjs/graphql',
        namedImports: ['ArgsType', 'Field', 'Int'],
    });
};
exports.generateNestJSCrudImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: '@nestjs/graphql',
        namedImports: ['Args', 'Context', 'Info', 'Query', 'Mutation', 'Resolver'],
    });
};
exports.generateNestJSEnumImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: '@nestjs/graphql',
        namedImports: ['registerEnumType'],
    });
};
exports.generateNestJSInputImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: '@nestjs/graphql',
        namedImports: ['Field', 'Float', 'ID', 'InputType', 'Int'],
    });
};
exports.generateNestJSModelImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: '@nestjs/graphql',
        namedImports: ['Field', 'Float', 'ID', 'Int', 'ObjectType'],
    });
};
exports.generateNestJSRelationsImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: '@nestjs/graphql',
        namedImports: ['Args', 'Context', 'ResolveField', 'Resolver', 'Root'],
    });
};
exports.generateGraphQLFieldsImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: 'graphql-fields',
        defaultImport: 'graphqlFields',
    });
    sourceFile.addImportDeclaration({
        moduleSpecifier: 'graphql',
        namedImports: ['GraphQLResolveInfo'],
    });
};
exports.generateGraphQLScalarImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: 'graphql-type-json',
        defaultImport: 'GraphQLJSON',
    });
};
exports.generatePrismaJsonTypeImport = (sourceFile, options, level = 0) => {
    var _a;
    sourceFile.addImportDeclaration({
        moduleSpecifier: (_a = options.absolutePrismaOutputPath) !== null && _a !== void 0 ? _a : (level === 0 ? './' : '') +
            path_1.default.posix.join(...Array(level).fill('..'), options.relativePrismaOutputPath),
        namedImports: ['JsonValue', 'InputJsonValue'],
    });
};
exports.generateClassTransformerImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: 'class-transformer',
        namedImports: ['plainToClass'],
    });
};
exports.generateClassTransformerDTOImport = (sourceFile) => {
    sourceFile.addImportDeclaration({
        moduleSpecifier: 'class-transformer',
        namedImports: [{ name: 'Type', alias: 'ClassTransformer__Type' }],
    });
};
exports.generateArgsBarrelFile = (sourceFile, argsTypeNames) => {
    sourceFile.addExportDeclarations(argsTypeNames
        .sort()
        .map((argTypeName) => ({
        moduleSpecifier: `./${argTypeName}`,
        namedExports: [argTypeName],
    })));
};
exports.generateModelsBarrelFile = (sourceFile, modelNames) => {
    sourceFile.addExportDeclarations(modelNames
        .sort()
        .map((modelName) => ({
        moduleSpecifier: `./${modelName}`,
        namedExports: [modelName],
    })));
};
exports.generateEnumsBarrelFile = (sourceFile, enumTypeNames) => {
    sourceFile.addExportDeclarations(enumTypeNames
        .sort()
        .map((enumTypeName) => ({
        moduleSpecifier: `./${enumTypeName}`,
        namedExports: [enumTypeName],
    })));
};
exports.generateInputsBarrelFile = (sourceFile, inputTypeNames) => {
    sourceFile.addExportDeclarations(inputTypeNames
        .sort()
        .map((inputTypeName) => ({
        moduleSpecifier: `./${inputTypeName}`,
        namedExports: [inputTypeName],
    })));
};
exports.generateOutputsBarrelFile = (sourceFile, outputTypeNames, hasSomeArgs) => {
    sourceFile.addExportDeclarations(outputTypeNames
        .sort()
        .map((outputTypeName) => ({
        moduleSpecifier: `./${outputTypeName}`,
        namedExports: [outputTypeName],
    })));
    if (hasSomeArgs) {
        sourceFile.addExportDeclaration({ moduleSpecifier: `./${config_1.argsFolderName}` });
    }
};
exports.generateIndexFile = (sourceFile, hasSomeRelations) => {
    sourceFile.addExportDeclarations([
        { moduleSpecifier: `./${config_1.enumsFolderName}` },
        { moduleSpecifier: `./${config_1.modelsFolderName}` },
        { moduleSpecifier: `./${config_1.resolversFolderName}/${config_1.crudResolversFolderName}` },
        ...(hasSomeRelations
            ? [
                {
                    moduleSpecifier: `./${config_1.resolversFolderName}/${config_1.relationsResolversFolderName}`,
                },
            ]
            : []),
        { moduleSpecifier: `./${config_1.resolversFolderName}/${config_1.inputsFolderName}` },
        { moduleSpecifier: `./${config_1.resolversFolderName}/${config_1.outputsFolderName}` },
    ]);
};
exports.generateResolversBarrelFile = (type, sourceFile, relationResolversData) => {
    relationResolversData
        .sort((a, b) => a.modelName > b.modelName ? 1 : a.modelName < b.modelName ? -1 : 0)
        .forEach(({ modelName, resolverName, actionResolverNames, argTypeNames }) => {
        sourceFile.addImportDeclaration({
            moduleSpecifier: `./${modelName}/${resolverName}`,
            namedImports: [resolverName].sort(),
        });
        sourceFile.addExportDeclaration({
            moduleSpecifier: `./${modelName}/${resolverName}`,
            namedExports: [resolverName],
        });
        if (actionResolverNames) {
            actionResolverNames.forEach((actionResolverName) => {
                sourceFile.addExportDeclaration({
                    moduleSpecifier: `./${modelName}/${actionResolverName}`,
                    namedExports: [actionResolverName],
                });
            });
        }
        if (argTypeNames.length) {
            sourceFile.addExportDeclaration({
                moduleSpecifier: `./${modelName}/args`,
            });
        }
    });
    const moduleName = type === 'crud' ? 'CrudResolversModule' : 'RelationsResolversModule';
    const providers = relationResolversData
        .sort((a, b) => a.modelName > b.modelName ? 1 : a.modelName < b.modelName ? -1 : 0)
        .map(({ resolverName }) => resolverName);
    sourceFile.addImportDeclaration({
        moduleSpecifier: '@nestjs/common',
        namedImports: ['Module'].sort(),
    });
    sourceFile.addClass({
        name: moduleName,
        isExported: true,
        decorators: [
            {
                name: 'Module',
                arguments: [
                    `{
  providers: [
    ${providers.join(`,\n    `)}
  ],
  exports: [
    ${providers.join(`,\n    `)}
  ]
}`,
                ],
            },
        ],
    });
};
const createImportGenerator = (elementsDirName) => {
    return (sourceFile, elementsNames, level = 1) => {
        const distinctElementsNames = [...new Set(elementsNames)].sort();
        for (const elementName of distinctElementsNames) {
            sourceFile.addImportDeclaration({
                moduleSpecifier: (level === 0 ? './' : '') +
                    path_1.default.posix.join(...Array(level).fill('..'), elementsDirName, elementName),
                // TODO: refactor to default exports
                // defaultImport: elementName,
                namedImports: [elementName],
            });
        }
    };
};
exports.generateModelsImports = createImportGenerator(config_1.modelsFolderName);
exports.generateEnumsImports = createImportGenerator(config_1.enumsFolderName);
exports.generateInputsImports = createImportGenerator(config_1.inputsFolderName);
exports.generateOutputsImports = createImportGenerator(config_1.outputsFolderName);
exports.generateArgsImports = createImportGenerator(config_1.argsFolderName);
//# sourceMappingURL=imports.js.map