"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const imports_1 = require("./imports");
const config_1 = require("./config");
const saveSourceFile_1 = tslib_1.__importDefault(require("../utils/saveSourceFile"));
const generateObjectTypeClassFromModel = async (project, baseDirPath, model, dmmfDocument, options) => {
    const dirPath = path_1.default.resolve(baseDirPath, config_1.modelsFolderName);
    const filePath = path_1.default.resolve(dirPath, `${model.typeName}.ts`);
    const sourceFile = project.createSourceFile(filePath, undefined, {
        overwrite: true,
    });
    imports_1.generateNestJSModelImport(sourceFile);
    imports_1.generateGraphQLScalarImport(sourceFile);
    imports_1.generateClassTransformerDTOImport(sourceFile);
    imports_1.generatePrismaJsonTypeImport(sourceFile, options, 1);
    imports_1.generateModelsImports(sourceFile, model.fields
        .filter((field) => field.kind === 'object')
        .filter((field) => field.type !== model.name)
        .map((field) => dmmfDocument.isModelName(field.type)
        ? dmmfDocument.getModelTypeName(field.type)
        : field.type));
    imports_1.generateEnumsImports(sourceFile, model.fields
        .filter((field) => field.kind === 'enum')
        .map((field) => field.type));
    sourceFile.addClass({
        name: model.typeName,
        isExported: true,
        decorators: [
            {
                name: 'ObjectType',
                arguments: [
                    `{
            isAbstract: true,
            description: ${model.docs ? `"${model.docs}"` : 'undefined'},
          }`,
                ],
            },
        ],
        properties: model.fields.map((field) => {
            const isOptional = !!field.relationName || !field.isRequired;
            return {
                name: field.name,
                type: field.fieldTSType,
                hasExclamationToken: !isOptional,
                hasQuestionToken: isOptional,
                trailingTrivia: '\r\n',
                decorators: [
                    ...(field.relationName || field.typeFieldAlias
                        ? []
                        : [
                            ...(field.type === 'DateTime'
                                ? [
                                    {
                                        name: 'ClassTransformer__Type',
                                        arguments: [`() => ${field.typeGraphQLType}`],
                                    },
                                ]
                                : []),
                            {
                                name: 'Field',
                                arguments: [
                                    `() => ${field.typeGraphQLType}`,
                                    `{
                        nullable: ${isOptional},
                        description: ${field.docs ? `"${field.docs}"` : 'undefined'},
                      }`,
                                ],
                            },
                        ]),
                ],
                ...(field.docs && {
                    docs: [{ description: field.docs }],
                }),
            };
        }),
        getAccessors: model.fields
            .filter((field) => field.typeFieldAlias && !field.relationName)
            .map((field) => {
            return {
                name: field.typeFieldAlias,
                returnType: field.fieldTSType,
                trailingTrivia: '\r\n',
                decorators: [
                    {
                        name: 'Field',
                        arguments: [
                            `() => ${field.typeGraphQLType}`,
                            `{
                  nullable: ${!field.isRequired},
                  description: ${field.docs ? `"${field.docs}"` : 'undefined'},
                }`,
                        ],
                    },
                ],
                statements: [`return this.${field.name};`],
                ...(field.docs && {
                    docs: [{ description: field.docs }],
                }),
            };
        }),
        ...(model.docs && {
            docs: [{ description: model.docs }],
        }),
    });
    await saveSourceFile_1.default(sourceFile);
};
exports.default = generateObjectTypeClassFromModel;
//# sourceMappingURL=model-type-class.js.map