"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const config_1 = require("../config");
const args_class_1 = tslib_1.__importDefault(require("../args-class"));
const imports_1 = require("../imports");
const saveSourceFile_1 = tslib_1.__importDefault(require("../../utils/saveSourceFile"));
const separate_action_1 = tslib_1.__importDefault(require("./separate-action"));
const helpers_1 = require("./helpers");
const generateCrudResolverClassFromMapping = async (project, baseDirPath, mapping, model, modelNames, options, dmmfDocument) => {
    const resolverName = `${model.typeName}CrudResolver`;
    const resolverDirPath = path_1.default.resolve(baseDirPath, config_1.resolversFolderName, config_1.crudResolversFolderName, model.typeName);
    const filePath = path_1.default.resolve(resolverDirPath, `${resolverName}.ts`);
    const sourceFile = project.createSourceFile(filePath, undefined, {
        overwrite: true,
    });
    imports_1.generateNestJSCrudImport(sourceFile);
    imports_1.generateGraphQLFieldsImport(sourceFile);
    await Promise.all(mapping.actions
        .filter((it) => it.argsTypeName)
        .map(async (action) => {
        await args_class_1.default(project, resolverDirPath, action.method.args, action.argsTypeName, dmmfDocument, options);
    }));
    const argTypeNames = mapping.actions
        .filter((it) => it.argsTypeName !== undefined)
        .map((it) => it.argsTypeName);
    if (argTypeNames.length) {
        const barrelExportSourceFile = project.createSourceFile(path_1.default.resolve(resolverDirPath, config_1.argsFolderName, 'index.ts'), undefined, { overwrite: true });
        imports_1.generateArgsBarrelFile(barrelExportSourceFile, mapping.actions
            .filter((it) => it.argsTypeName !== undefined)
            .map((it) => it.argsTypeName));
        await saveSourceFile_1.default(barrelExportSourceFile);
    }
    imports_1.generateArgsImports(sourceFile, argTypeNames, 0);
    const distinctOutputTypesNames = [
        ...new Set(mapping.actions.map((it) => it.outputTypeName)),
    ];
    imports_1.generateModelsImports(sourceFile, distinctOutputTypesNames
        .filter((typeName) => modelNames.includes(typeName))
        .map((typeName) => dmmfDocument.isModelName(typeName)
        ? dmmfDocument.getModelTypeName(typeName)
        : typeName), 3);
    imports_1.generateClassTransformerImport(sourceFile);
    imports_1.generateOutputsImports(sourceFile, distinctOutputTypesNames.filter((typeName) => !modelNames.includes(typeName)), 2);
    sourceFile.addClass({
        name: resolverName,
        isExported: true,
        decorators: [
            {
                name: 'Resolver',
                arguments: [`() => ${model.typeName}`],
            },
        ],
        methods: await Promise.all(mapping.actions.map((action) => helpers_1.generateCrudResolverClassMethodDeclaration(action, model.typeName, dmmfDocument, mapping))),
    });
    const actionResolverNames = await Promise.all(mapping.actions.map((action) => separate_action_1.default(project, baseDirPath, model, action, modelNames, mapping, dmmfDocument)));
    await saveSourceFile_1.default(sourceFile);
    return {
        modelName: model.typeName,
        resolverName,
        actionResolverNames,
        argTypeNames,
    };
};
exports.default = generateCrudResolverClassFromMapping;
//# sourceMappingURL=full-crud.js.map