"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateCrudResolverClassMethodDeclaration = void 0;
const helpers_1 = require("../helpers");
exports.generateCrudResolverClassMethodDeclaration = (action, typeName, dmmfDocument, mapping) => {
    const returnTSType = helpers_1.getFieldTSType(action.method.outputType, dmmfDocument, false, mapping.model, typeName);
    return {
        name: action.name,
        isAsync: true,
        returnType: `Promise<${returnTSType}>`,
        decorators: [
            {
                name: `${action.operation}`,
                arguments: [
                    `() => ${helpers_1.getGraphQLType(action.method.outputType, dmmfDocument, mapping.model, typeName)}`,
                    `{
${[
                        `nullable: ${!action.method.outputType.isRequired}`,
                        `description: undefined`,
                    ].join(',\n')}
          }`,
                ],
            },
        ],
        parameters: [
            {
                name: 'ctx',
                // TODO: import custom `ContextType`
                type: 'any',
                decorators: [{ name: 'Context', arguments: [] }],
            },
            ...(action.kind === 'aggregate'
                ? [
                    {
                        name: 'info',
                        type: 'GraphQLResolveInfo',
                        decorators: [{ name: 'Info', arguments: [] }],
                    },
                ]
                : []),
            ...(!action.argsTypeName
                ? []
                : [
                    {
                        name: 'args',
                        type: action.argsTypeName,
                        decorators: [{ name: 'Args', arguments: [] }],
                    },
                ]),
        ],
        statements: action.kind === 'aggregate'
            ? [
                `const transformFields = (fields: Record<string, any>): Record<string, any> => {
              return Object.fromEntries(
                Object.entries(fields)
                  .filter(([key, value]) => !key.startsWith("_"))
                  .map<[string, any]>(([key, value]) => {
                    if (Object.keys(value).length === 0) {
                      return [key, true];
                    }
                    return [key, transformFields(value)];
                  }),
              );
            }`,
                `return ctx.prisma.${mapping.collectionName}.${action.kind}({
              ...args,
              ...transformFields(graphqlFields(info as any)),
            });`,
            ]
            : [
                `return plainToClass(${helpers_1.getGraphQLType(action.method.outputType, dmmfDocument, mapping.model, typeName).replace(/\[|\]/g, '')}, await ctx.prisma.${mapping.collectionName}.${action.kind}(${action.argsTypeName ? 'args' : ''}) as ${helpers_1.getGraphQLType(action.method.outputType, dmmfDocument, mapping.model, typeName)});`,
            ],
    };
};
//# sourceMappingURL=helpers.js.map