"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const helpers_1 = require("../helpers");
const config_1 = require("../config");
const imports_1 = require("../imports");
const saveSourceFile_1 = tslib_1.__importDefault(require("../../utils/saveSourceFile"));
const helpers_2 = require("./helpers");
const types_1 = require("../dmmf/types");
const generateActionResolverClass = async (project, baseDirPath, model, action, modelNames, mapping, dmmfDocument) => {
    const actionResolverName = `${helpers_1.pascalCase(action.kind)}${model.typeName}Resolver`;
    const resolverDirPath = path_1.default.resolve(baseDirPath, config_1.resolversFolderName, config_1.crudResolversFolderName, model.typeName);
    const filePath = path_1.default.resolve(resolverDirPath, `${actionResolverName}.ts`);
    const sourceFile = project.createSourceFile(filePath, undefined, {
        overwrite: true,
    });
    imports_1.generateNestJSCrudImport(sourceFile);
    if (action.kind === types_1.DMMF.ModelAction.aggregate) {
        imports_1.generateGraphQLFieldsImport(sourceFile);
    }
    if (action.argsTypeName) {
        imports_1.generateArgsImports(sourceFile, [action.argsTypeName], 0);
    }
    imports_1.generateModelsImports(sourceFile, [model.name, action.outputTypeName]
        .filter((name) => modelNames.includes(name))
        .map((typeName) => dmmfDocument.isModelName(typeName)
        ? dmmfDocument.getModelTypeName(typeName)
        : typeName), 3);
    imports_1.generateClassTransformerImport(sourceFile);
    imports_1.generateOutputsImports(sourceFile, [action.outputTypeName].filter((name) => !modelNames.includes(name)), 2);
    sourceFile.addClass({
        name: actionResolverName,
        isExported: true,
        decorators: [
            {
                name: 'Resolver',
                arguments: [`() => ${model.typeName}`],
            },
        ],
        methods: [
            helpers_2.generateCrudResolverClassMethodDeclaration(action, model.typeName, dmmfDocument, mapping),
        ],
    });
    await saveSourceFile_1.default(sourceFile);
    return actionResolverName;
};
exports.default = generateActionResolverClass;
//# sourceMappingURL=separate-action.js.map